boto v2.26.0 — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »

# boto v2.26.0

date: | 2014/02/27

This release adds support for MFA tokens in the AWS STS `assume_role` & the introduction of the `boto.rds2` module (which has full support for the entire RDS API). It also includes the addition of request hooks & many bugfixes.

## Changes

- Added support for MFA in STS AssumeRole. (commit 899810c)
- Fixed how DynamoDB v2 works with Global Secondary Indexes. (issue 2122, commit f602c95)
- Add request hooks and request logger. (issue 2125, commit e8b20fe)
- Don’t pull the security token from the environment or config when a caller supplies the access key and secret. (issue 2123, commit 4df1694)
- Read EvaluateTargetHealth from Route53 resource record set. (issue 2120, commit 0a97158)
- Prevent implicit string decode in hmac-v4 handlers. (issue 2037, issue 2033, commit 8e56a5f)
- Updated Datapipeline to include all current regions. (issue 2121, commit dff5e3e)
- Bug fix for Google Storage generate_url authentication. (issue 2116, issue 2108, commit 5a50932)
- Handle JSON error responses in BotoServerError. (issue 2113, issue 2077, commit 221085e)
- Corrected a typo in SQS tutorial. (issue 2114, commit 7ed41f7)
- Add CloudFormation template capabilities support. (issue 2111, issue 2075, commit 65a4323)
- Add SWF layer1_decisions to docs. (issue 2110, issue 2062, commit 6039cc9)
- Add support for request intervals in health checks. (issue 2109, commit 660b01a)
- Added checks for invalid regions to the `bin` scripts (issue 2107, commit bbb9f1e)
- Better error output for unknown region - (issue 2041, issue 1983, commit cd63f92)
- Added certificate tests for CloudTrail. (issue 2106, commit a7e9b4c)
- Updated Kinesis endpoints. (commit 7bd4b6e)
- Finished implementation of RDS’s DescribeDBLogFiles. (issue 2084, commit f3c706c)
- Added support for RDS log file downloading. (issue 2086, issue 1993, commit 4c51841)
- Added some unit tests for CloudFront. (issue 2076, commit 6c46b1d)
- GS should ignore restore_headers as they are never set. (issue 2067, commit f02aeb3)
- Update CloudFormation to support the latest API. (issue 2101, commit ea1b1b6)
- Added Route53 health checks. (issue 2054, commit 9028f7d)
- Merge branch ‘rds2’ into develop Fixes #2097. (issue 2097, commit 6843c16)
- Fix Param class convert method (issue 2094, commit 5cd4598)
- Added support for Route53 aliasing. (issue 2096, commit df5fa40)
- Removed the dependence on `example.com` within the Route53 tests. (issue 2098, commit 6ce9e0f)
- Fixed `has_item` support in DynamoDB v2. (issue 2090, commit aada5d3)
- Fix a little typo bug in the S3 tutorial. (issue 2088, commit c091d27)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »